@@ -130,7 +130,9 @@ class Column(PropertyObject, gobject.GObject):
           (where to put the ...) is needed.
       - B{font-desc}: str I{""}
         - A string passed to pango.FontDescription, for instance "Sans" or
-          "Monospace 28".
+      - B{column}: str None
+        - A string referencing to another column. If this is set a new column
+          will not be created and the column will be packed into the other.
     """
     __gtype_name__ = 'Column'
     gproperty('attribute', str, flags=(gobject.PARAM_READWRITE | gobject.PARAM_CONSTRUCT_ONLY))
@@ -155,6 +157,7 @@ class Column(PropertyObject, gobject.GObject):
     gproperty('expander', bool, False)
     gproperty('ellipsize', pango.EllipsizeMode, default=pango.ELLIPSIZE_NONE)
     gproperty('font-desc', str)
+    gproperty('column', str)
     #gproperty('title_pixmap', str)
 
     # This can be set in subclasses, to be able to allow custom
@@ -181,7 +184,7 @@ class Column(PropertyObject, gobject.GObject):
         @param data_type: the type of the attribute that will be inserted
             into the column.
 
-        @keyword title_pixmap: (TODO) if set to a filename a pixmap will be
+        @note: title_pixmap: (TODO) if set to a filename a pixmap will be
             used *instead* of the title set. The title string will still be
             used to identify the column in the column selection and in a
             tooltip, if a tooltip is not set.
@@ -249,7 +252,11 @@ class Column(PropertyObject, gobject.GObject):
         if (self.data_type is bool and self.format):
             raise TypeError("format is not supported for boolean columns")
 
-        treeview_column = gtk.TreeViewColumn()
+        if not self.column:
+            treeview_column = gtk.TreeViewColumn()
+        else:
+            other_column = objectlist.get_column_by_name(self.column)
+            treeview_column = objectlist.get_treeview_column(other_column)
 
         renderer, renderer_prop = self._guess_renderer_for_type(model)
         if self.on_attach_renderer:
@@ -283,6 +290,7 @@ class Column(PropertyObject, gobject.GObject):
             cell_data_func = self.cell_data_func
 
         treeview_column.pack_start(renderer)
+
         treeview_column.set_cell_data_func(renderer, cell_data_func,
                                            (self, renderer_prop))
         treeview_column.set_visible(self.visible)
@@ -305,9 +313,6 @@ class Column(PropertyObject, gobject.GObject):
             if not issubclass(self.data_type, bool):
                 raise TypeError("You can only use radio for boolean columns")
 
-        if self.expander:
-            self._treeview.set_expander_column(treeview_column)
-
         # typelist here may be none. It's okay; justify_columns will try
         # and use the specified justifications and if not present will
         # not touch the column. When typelist is not set,
@@ -766,6 +771,7 @@ class ObjectList(PropertyObject, gtk.ScrolledWindow):
                  sortable=False,
                  model=None):
         """
+        Create a new ObjectList object.
         @param columns:       a list of L{Column}s
         @param objects:       a list of objects to be inserted or None
         @param mode:          selection mode
@@ -1117,6 +1123,9 @@ class ObjectList(PropertyObject, gtk.ScrolledWindow):
 
     def _attach_column(self, column):
         treeview_column = column.attach(self)
+        if column.column:
+            return
+
         # we need to set our own widget because otherwise
         # __get_column_button won't work
 
@@ -1151,14 +1160,14 @@ class ObjectList(PropertyObject, gtk.ScrolledWindow):
             self._treeview.set_search_equal_func(
                 self._treeview_search_equal_func, column)
 
-        if column.expander:
-            self._treeview.set_expander_column(treeview_column)
-
         if column.tooltip:
             widget = self._get_column_button(treeview_column)
             if widget is not None:
                 self._tooltips.set_tip(widget, column.tooltip)
 
+        if column.expander:
+            self._treeview.set_expander_column(treeview_column)
+
     # selection methods
     def _select_and_focus_row(self, row_iter):
         self._treeview.set_cursor(self._model[row_iter].path)
@@ -1390,6 +1399,7 @@ class ObjectList(PropertyObject, gtk.ScrolledWindow):
 
     def set_columns(self, columns):
         """
+        Set columns.
         @param columns: a sequence of L{Column} objects.
         """
 
@@ -1636,7 +1646,7 @@ class ObjectList(PropertyObject, gtk.ScrolledWindow):
 
     def get_selected_row_number(self):
         """
-        @returns: the selected row number or None if no rows were selected
+        Get the selected row number or None if no rows were selected
         """
         selection = self._treeview.get_selection()
         if selection.get_mode() == gtk.SELECTION_MULTIPLE:
@@ -1663,6 +1673,7 @@ class ObjectList(PropertyObject, gtk.ScrolledWindow):
 
     def set_headers_visible(self, value):
         """
+        Show or hide the headers.
         @param value: if true, shows the headers, if false hide then
         """
         self._treeview.set_headers_visible(value)
@@ -1700,7 +1711,7 @@ class ObjectList(PropertyObject, gtk.ScrolledWindow):
 
     def get_dnd_targets(self):
         """
-        @returns: a list of dnd targets ObjectList supports
+        Get a list of dnd targets ObjectList supports
         """
         return [
             ('OBJECTLIST_ROW', 0, 10),
@@ -1759,6 +1770,7 @@ class ObjectTree(ObjectList):
 
     def append(self, parent, instance, select=False):
         """
+        Append the selected row in an instance.
         @param parent: Object or None, representing the parent
         @param instance: the instance to be added
         @param select: select the row
@@ -1768,6 +1780,7 @@ class ObjectTree(ObjectList):
 
     def prepend(self, parent, instance, select=False):
         """
+        Prepend the selected row in an instance.
         @param parent: Object or None, representing the parent
         @param instance: the instance to be added
         @param select: select the row
@@ -1818,6 +1831,7 @@ class ListLabel(gtk.HBox):
     def __init__(self, klist, column, label='', value_format='%s',
                  font_desc=None):
         """
+        Constructor.
         @param klist:        list to follow
         @type klist:         kiwi.ui.objectlist.ObjectList
         @param column:       name of a column in a klist
@@ -1946,7 +1960,7 @@ class SummaryLabel(ListLabel):
         attr = column.attribute
         get_attribute = column.get_attribute
 
-        value = sum([get_attribute(obj, attr, 0) for obj in self._klist],
+        value = sum([get_attribute(obj, attr, 0) or 0 for obj in self._klist],
                     column.data_type('0'))
 
         self.set_value(column.as_string(value))
